Class: Google::Cloud::CloudDMS::V1::GenerateSshScriptRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/clouddms/v1/clouddms.rb

Overview

Request message for 'GenerateSshScript' request.

Instance Attribute Summary collapse

Instance Attribute Details

#migration_job::String

Returns Name of the migration job resource to generate the SSH script.

Returns:

  • (::String)

    Name of the migration job resource to generate the SSH script.



248
249
250
251
# File 'proto_docs/google/cloud/clouddms/v1/clouddms.rb', line 248

class GenerateSshScriptRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vm::String

Returns Required. Bastion VM Instance name to use or to create.

Returns:

  • (::String)

    Required. Bastion VM Instance name to use or to create.



248
249
250
251
# File 'proto_docs/google/cloud/clouddms/v1/clouddms.rb', line 248

class GenerateSshScriptRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vm_creation_config::Google::Cloud::CloudDMS::V1::VmCreationConfig

Returns The VM creation configuration

Note: The following fields are mutually exclusive: vm_creation_config, vm_selection_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::CloudDMS::V1::VmCreationConfig)

    The VM creation configuration

    Note: The following fields are mutually exclusive: vm_creation_config, vm_selection_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



248
249
250
251
# File 'proto_docs/google/cloud/clouddms/v1/clouddms.rb', line 248

class GenerateSshScriptRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vm_port::Integer

Returns The port that will be open on the bastion host.

Returns:

  • (::Integer)

    The port that will be open on the bastion host.



248
249
250
251
# File 'proto_docs/google/cloud/clouddms/v1/clouddms.rb', line 248

class GenerateSshScriptRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vm_selection_config::Google::Cloud::CloudDMS::V1::VmSelectionConfig

Returns The VM selection configuration

Note: The following fields are mutually exclusive: vm_selection_config, vm_creation_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::CloudDMS::V1::VmSelectionConfig)

    The VM selection configuration

    Note: The following fields are mutually exclusive: vm_selection_config, vm_creation_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



248
249
250
251
# File 'proto_docs/google/cloud/clouddms/v1/clouddms.rb', line 248

class GenerateSshScriptRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end