Class: Google::Cloud::CloudDMS::V1::SeedConversionWorkspaceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/clouddms/v1/clouddms.rb

Overview

Request message for 'SeedConversionWorkspace' request.

Instance Attribute Summary collapse

Instance Attribute Details

#auto_commit::Boolean

Returns Should the conversion workspace be committed automatically after the seed operation.

Returns:

  • (::Boolean)

    Should the conversion workspace be committed automatically after the seed operation.



853
854
855
856
# File 'proto_docs/google/cloud/clouddms/v1/clouddms.rb', line 853

class SeedConversionWorkspaceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#destination_connection_profile::String

Returns Optional. Fully qualified (Uri) name of the destination connection profile.

Note: The following fields are mutually exclusive: destination_connection_profile, source_connection_profile. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Fully qualified (Uri) name of the destination connection profile.

    Note: The following fields are mutually exclusive: destination_connection_profile, source_connection_profile. If a field in that set is populated, all other fields in the set will automatically be cleared.



853
854
855
856
# File 'proto_docs/google/cloud/clouddms/v1/clouddms.rb', line 853

class SeedConversionWorkspaceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Name of the conversion workspace resource to seed with new database structure, in the form of: projects/{project}/locations/{location}/conversionWorkspaces/{conversion_workspace}.

Returns:

  • (::String)

    Name of the conversion workspace resource to seed with new database structure, in the form of: projects/{project}/locations/{location}/conversionWorkspaces/{conversion_workspace}.



853
854
855
856
# File 'proto_docs/google/cloud/clouddms/v1/clouddms.rb', line 853

class SeedConversionWorkspaceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_connection_profile::String

Returns Optional. Fully qualified (Uri) name of the source connection profile.

Note: The following fields are mutually exclusive: source_connection_profile, destination_connection_profile. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Fully qualified (Uri) name of the source connection profile.

    Note: The following fields are mutually exclusive: source_connection_profile, destination_connection_profile. If a field in that set is populated, all other fields in the set will automatically be cleared.



853
854
855
856
# File 'proto_docs/google/cloud/clouddms/v1/clouddms.rb', line 853

class SeedConversionWorkspaceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end