Class: Google::Cloud::CloudDMS::V1::SqlAclEntry

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb

Overview

An entry for an Access Control list.

Instance Attribute Summary collapse

Instance Attribute Details

#expire_time::Google::Protobuf::Timestamp

Returns The time when this access control entry expires in RFC 3339 format, for example: 2012-11-15T16:19:00.094Z.

Note: The following fields are mutually exclusive: expire_time, ttl. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Timestamp)

    The time when this access control entry expires in RFC 3339 format, for example: 2012-11-15T16:19:00.094Z.

    Note: The following fields are mutually exclusive: expire_time, ttl. If a field in that set is populated, all other fields in the set will automatically be cleared.



252
253
254
255
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 252

class SqlAclEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#label::String

Returns A label to identify this entry.

Returns:

  • (::String)

    A label to identify this entry.



252
253
254
255
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 252

class SqlAclEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ttl::Google::Protobuf::Duration

Returns Input only. The time-to-leave of this access control entry.

Note: The following fields are mutually exclusive: ttl, expire_time. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Duration)

    Input only. The time-to-leave of this access control entry.

    Note: The following fields are mutually exclusive: ttl, expire_time. If a field in that set is populated, all other fields in the set will automatically be cleared.



252
253
254
255
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 252

class SqlAclEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::String

Returns The allowlisted value for the access control list.

Returns:

  • (::String)

    The allowlisted value for the access control list.



252
253
254
255
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 252

class SqlAclEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end