Class: Google::Cloud::CloudDMS::V1::MappingRule
- Inherits:
-
Object
- Object
- Google::Cloud::CloudDMS::V1::MappingRule
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb
Overview
Definition of a transformation that is to be applied to a group of entities in the source schema. Several such transformations can be applied to an entity sequentially to define the corresponding entity in the target schema.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#conditional_column_set_value ⇒ ::Google::Cloud::CloudDMS::V1::ConditionalColumnSetValue
Optional.
-
#convert_rowid_column ⇒ ::Google::Cloud::CloudDMS::V1::ConvertRowIdToColumn
Optional.
-
#display_name ⇒ ::String
Optional.
-
#entity_move ⇒ ::Google::Cloud::CloudDMS::V1::EntityMove
Optional.
-
#filter ⇒ ::Google::Cloud::CloudDMS::V1::MappingRuleFilter
Required.
-
#filter_table_columns ⇒ ::Google::Cloud::CloudDMS::V1::FilterTableColumns
Optional.
-
#multi_column_data_type_change ⇒ ::Google::Cloud::CloudDMS::V1::MultiColumnDatatypeChange
Optional.
-
#multi_entity_rename ⇒ ::Google::Cloud::CloudDMS::V1::MultiEntityRename
Optional.
-
#name ⇒ ::String
Full name of the mapping rule resource, in the form of: projects/{project}/locations/{location}/conversionWorkspaces/{set}/mappingRule/{rule}.
-
#revision_create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#revision_id ⇒ ::String
readonly
Output only.
-
#rule_order ⇒ ::Integer
Required.
-
#rule_scope ⇒ ::Google::Cloud::CloudDMS::V1::DatabaseEntityType
Required.
-
#set_table_primary_key ⇒ ::Google::Cloud::CloudDMS::V1::SetTablePrimaryKey
Optional.
-
#single_column_change ⇒ ::Google::Cloud::CloudDMS::V1::SingleColumnChange
Optional.
-
#single_entity_rename ⇒ ::Google::Cloud::CloudDMS::V1::SingleEntityRename
Optional.
-
#single_package_change ⇒ ::Google::Cloud::CloudDMS::V1::SinglePackageChange
Optional.
-
#source_sql_change ⇒ ::Google::Cloud::CloudDMS::V1::SourceSqlChange
Optional.
-
#state ⇒ ::Google::Cloud::CloudDMS::V1::MappingRule::State
Optional.
Instance Attribute Details
#conditional_column_set_value ⇒ ::Google::Cloud::CloudDMS::V1::ConditionalColumnSetValue
Returns Optional. Rule to specify how the data contained in a column should be transformed (such as trimmed, rounded, etc) provided that the data meets certain criteria.
Note: The following fields are mutually exclusive: conditional_column_set_value, single_entity_rename, multi_entity_rename, entity_move, single_column_change, multi_column_data_type_change, convert_rowid_column, set_table_primary_key, single_package_change, source_sql_change, filter_table_columns. If a field in that set is populated, all other fields in the set will automatically be cleared.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#convert_rowid_column ⇒ ::Google::Cloud::CloudDMS::V1::ConvertRowIdToColumn
Returns Optional. Rule to specify how multiple tables should be converted with an additional rowid column.
Note: The following fields are mutually exclusive: convert_rowid_column, single_entity_rename, multi_entity_rename, entity_move, single_column_change, multi_column_data_type_change, conditional_column_set_value, set_table_primary_key, single_package_change, source_sql_change, filter_table_columns. If a field in that set is populated, all other fields in the set will automatically be cleared.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#display_name ⇒ ::String
Returns Optional. A human readable name.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#entity_move ⇒ ::Google::Cloud::CloudDMS::V1::EntityMove
Returns Optional. Rule to specify how multiple entities should be relocated into a different schema.
Note: The following fields are mutually exclusive: entity_move, single_entity_rename, multi_entity_rename, single_column_change, multi_column_data_type_change, conditional_column_set_value, convert_rowid_column, set_table_primary_key, single_package_change, source_sql_change, filter_table_columns. If a field in that set is populated, all other fields in the set will automatically be cleared.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#filter ⇒ ::Google::Cloud::CloudDMS::V1::MappingRuleFilter
Returns Required. The rule filter.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#filter_table_columns ⇒ ::Google::Cloud::CloudDMS::V1::FilterTableColumns
Returns Optional. Rule to specify the list of columns to include or exclude from a table.
Note: The following fields are mutually exclusive: filter_table_columns, single_entity_rename, multi_entity_rename, entity_move, single_column_change, multi_column_data_type_change, conditional_column_set_value, convert_rowid_column, set_table_primary_key, single_package_change, source_sql_change. If a field in that set is populated, all other fields in the set will automatically be cleared.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#multi_column_data_type_change ⇒ ::Google::Cloud::CloudDMS::V1::MultiColumnDatatypeChange
Returns Optional. Rule to specify how multiple columns should be converted to a different data type.
Note: The following fields are mutually exclusive: multi_column_data_type_change, single_entity_rename, multi_entity_rename, entity_move, single_column_change, conditional_column_set_value, convert_rowid_column, set_table_primary_key, single_package_change, source_sql_change, filter_table_columns. If a field in that set is populated, all other fields in the set will automatically be cleared.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#multi_entity_rename ⇒ ::Google::Cloud::CloudDMS::V1::MultiEntityRename
Returns Optional. Rule to specify how multiple entities should be renamed.
Note: The following fields are mutually exclusive: multi_entity_rename, single_entity_rename, entity_move, single_column_change, multi_column_data_type_change, conditional_column_set_value, convert_rowid_column, set_table_primary_key, single_package_change, source_sql_change, filter_table_columns. If a field in that set is populated, all other fields in the set will automatically be cleared.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#name ⇒ ::String
Returns Full name of the mapping rule resource, in the form of: projects/{project}/locations/{location}/conversionWorkspaces/{set}/mappingRule/{rule}.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#revision_create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp that the revision was created.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#revision_id ⇒ ::String (readonly)
Returns Output only. The revision ID of the mapping rule. A new revision is committed whenever the mapping rule is changed in any way. The format is an 8-character hexadecimal string.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#rule_order ⇒ ::Integer
Returns Required. The order in which the rule is applied. Lower order rules are applied before higher value rules so they may end up being overridden.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#rule_scope ⇒ ::Google::Cloud::CloudDMS::V1::DatabaseEntityType
Returns Required. The rule scope.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#set_table_primary_key ⇒ ::Google::Cloud::CloudDMS::V1::SetTablePrimaryKey
Returns Optional. Rule to specify the primary key for a table
Note: The following fields are mutually exclusive: set_table_primary_key, single_entity_rename, multi_entity_rename, entity_move, single_column_change, multi_column_data_type_change, conditional_column_set_value, convert_rowid_column, single_package_change, source_sql_change, filter_table_columns. If a field in that set is populated, all other fields in the set will automatically be cleared.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#single_column_change ⇒ ::Google::Cloud::CloudDMS::V1::SingleColumnChange
Returns Optional. Rule to specify how a single column is converted.
Note: The following fields are mutually exclusive: single_column_change, single_entity_rename, multi_entity_rename, entity_move, multi_column_data_type_change, conditional_column_set_value, convert_rowid_column, set_table_primary_key, single_package_change, source_sql_change, filter_table_columns. If a field in that set is populated, all other fields in the set will automatically be cleared.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#single_entity_rename ⇒ ::Google::Cloud::CloudDMS::V1::SingleEntityRename
Returns Optional. Rule to specify how a single entity should be renamed.
Note: The following fields are mutually exclusive: single_entity_rename, multi_entity_rename, entity_move, single_column_change, multi_column_data_type_change, conditional_column_set_value, convert_rowid_column, set_table_primary_key, single_package_change, source_sql_change, filter_table_columns. If a field in that set is populated, all other fields in the set will automatically be cleared.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#single_package_change ⇒ ::Google::Cloud::CloudDMS::V1::SinglePackageChange
Returns Optional. Rule to specify how a single package is converted.
Note: The following fields are mutually exclusive: single_package_change, single_entity_rename, multi_entity_rename, entity_move, single_column_change, multi_column_data_type_change, conditional_column_set_value, convert_rowid_column, set_table_primary_key, source_sql_change, filter_table_columns. If a field in that set is populated, all other fields in the set will automatically be cleared.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#source_sql_change ⇒ ::Google::Cloud::CloudDMS::V1::SourceSqlChange
Returns Optional. Rule to change the sql code for an entity, for example, function, procedure.
Note: The following fields are mutually exclusive: source_sql_change, single_entity_rename, multi_entity_rename, entity_move, single_column_change, multi_column_data_type_change, conditional_column_set_value, convert_rowid_column, set_table_primary_key, single_package_change, filter_table_columns. If a field in that set is populated, all other fields in the set will automatically be cleared.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |
#state ⇒ ::Google::Cloud::CloudDMS::V1::MappingRule::State
Returns Optional. The mapping rule state.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'proto_docs/google/cloud/clouddms/v1/conversionworkspace_resources.rb', line 317 class MappingRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The current mapping rule state such as enabled, disabled or deleted. module State # The state of the mapping rule is unknown. STATE_UNSPECIFIED = 0 # The rule is enabled. ENABLED = 1 # The rule is disabled. DISABLED = 2 # The rule is logically deleted. DELETED = 3 end end |