Class: Google::Cloud::CloudDMS::V1::OracleConnectionProfile
- Inherits:
-
Object
- Object
- Google::Cloud::CloudDMS::V1::OracleConnectionProfile
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb
Overview
Specifies connection parameters required specifically for Oracle databases.
Instance Attribute Summary collapse
-
#database_service ⇒ ::String
Required.
-
#forward_ssh_connectivity ⇒ ::Google::Cloud::CloudDMS::V1::ForwardSshTunnelConnectivity
Forward SSH tunnel connectivity.
-
#host ⇒ ::String
Required.
-
#password ⇒ ::String
Required.
-
#password_set ⇒ ::Boolean
readonly
Output only.
-
#port ⇒ ::Integer
Required.
-
#private_connectivity ⇒ ::Google::Cloud::CloudDMS::V1::PrivateConnectivity
Private connectivity.
-
#ssl ⇒ ::Google::Cloud::CloudDMS::V1::SslConfig
SSL configuration for the connection to the source Oracle database.
-
#static_service_ip_connectivity ⇒ ::Google::Cloud::CloudDMS::V1::StaticServiceIpConnectivity
Static Service IP connectivity.
-
#username ⇒ ::String
Required.
Instance Attribute Details
#database_service ⇒ ::String
Returns Required. Database service for the Oracle connection.
189 190 191 192 |
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 189 class OracleConnectionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#forward_ssh_connectivity ⇒ ::Google::Cloud::CloudDMS::V1::ForwardSshTunnelConnectivity
Returns Forward SSH tunnel connectivity.
Note: The following fields are mutually exclusive: forward_ssh_connectivity, static_service_ip_connectivity, private_connectivity. If a field in that set is populated, all other fields in the set will automatically be cleared.
189 190 191 192 |
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 189 class OracleConnectionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#host ⇒ ::String
Returns Required. The IP or hostname of the source Oracle database.
189 190 191 192 |
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 189 class OracleConnectionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#password ⇒ ::String
Required. Input only. The password for the user that Database Migration Service will be using to connect to the database. This field is not returned on request, and the value is encrypted when stored in Database Migration Service.
189 190 191 192 |
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 189 class OracleConnectionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#password_set ⇒ ::Boolean (readonly)
Returns Output only. Indicates whether a new password is included in the request.
189 190 191 192 |
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 189 class OracleConnectionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#port ⇒ ::Integer
Returns Required. The network port of the source Oracle database.
189 190 191 192 |
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 189 class OracleConnectionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#private_connectivity ⇒ ::Google::Cloud::CloudDMS::V1::PrivateConnectivity
Returns Private connectivity.
Note: The following fields are mutually exclusive: private_connectivity, static_service_ip_connectivity, forward_ssh_connectivity. If a field in that set is populated, all other fields in the set will automatically be cleared.
189 190 191 192 |
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 189 class OracleConnectionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ssl ⇒ ::Google::Cloud::CloudDMS::V1::SslConfig
Returns SSL configuration for the connection to the source Oracle database.
- Only
SERVER_ONLYconfiguration is supported for Oracle SSL. - SSL is supported for Oracle versions 12 and above.
189 190 191 192 |
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 189 class OracleConnectionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#static_service_ip_connectivity ⇒ ::Google::Cloud::CloudDMS::V1::StaticServiceIpConnectivity
Returns Static Service IP connectivity.
Note: The following fields are mutually exclusive: static_service_ip_connectivity, forward_ssh_connectivity, private_connectivity. If a field in that set is populated, all other fields in the set will automatically be cleared.
189 190 191 192 |
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 189 class OracleConnectionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#username ⇒ ::String
Returns Required. The username that Database Migration Service will use to connect to the database. The value is encrypted when stored in Database Migration Service.
189 190 191 192 |
# File 'proto_docs/google/cloud/clouddms/v1/clouddms_resources.rb', line 189 class OracleConnectionProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |